@@ -4,7 +4,7 @@ Get the MAC address of an interface
 BSD code
 
 Programmed by Bastian Ballmann
-Last update: 01.12.2004
+Last update: 09.02.2006
 
 This program is free software; you can redistribute 
 it and/or modify it under the terms of the 
@@ -28,7 +28,7 @@ int get_mac_bsd(u_char *dev, char *mac)
   struct ifaddrs *iface;
 
   if(strlen(mac) > 0)
-    strcpy(mac,"unkown");
+    strcpy(mac,"unknown");
   else
     return -1;
 
