@@ -32,12 +32,11 @@ int send_packet_bsd(u_char *dev, u_char *packet, u_int packetsize)
   char bpfdev[10];
 
   if( (strlen(dev) == 0) ||
-      (strlen(packet) == 0) ||
       (packetsize == 0) )
-    return -1;
+    return 0;
 
   // Open a bpf device
-  for(i = 0; i < 3; i++)
+  for(i = 0; i < 9; i++)
     {
       sprintf(bpfdev,"/dev/bpf%d",i);
       if((bpffd = open(bpfdev,O_WRONLY)) > 0)
@@ -49,6 +48,7 @@ int send_packet_bsd(u_char *dev, u_char *packet, u_int packetsize)
   if(bpffd < 0)
     {
       perror("open bpf");
+      return 0;
     }
   else
     {
@@ -64,5 +64,5 @@ int send_packet_bsd(u_char *dev, u_char *packet, u_int packetsize)
       close(bpffd);
     }
 
-  return 0;
+  return 1;
 }
