@@ -3,7 +3,7 @@
 # Perl ARP Extension test file
 #
 # Programmed by Bastian Ballmann
-# Last update: 23.11.2005
+# Last update: 31.01.2007
 #
 # This program is free software; you can redistribute 
 # it and/or modify it under the terms of the 
@@ -18,20 +18,36 @@
 
 use ExtUtils::testlib;
 use Net::ARP;
-use Net::Pcap;
 
-my $errbuf;
-my $dev = Net::Pcap::lookupdev(\$errbuf);
+BEGIN
+{
+    eval{ require Net::Pcap; };
+              
+    if($@ =~ /^Can\'t\slocate/)
+    {
+        $dev = "eth0";
+    }
+    else
+    {
+   	import Net::Pcap;
+        $dev = Net::Pcap::lookupdev(\$errbuf);
+    }
+}
 
-Net::ARP::send_packet($dev,                           # network interface
+print "Sending ARP reply packet via dev $dev... ";
+
+$ret = Net::ARP::send_packet($dev,                           # network interface
 		      '127.0.0.1',                    # source ip
 	              '127.0.0.1',                    # destination ip
 		      'aa:bb:cc:aa:bb:cc',            # source mac
 	              'ff:ff:ff:ff:ff:ff',            # destination mac
 	              'reply');                       # ARP operation 
 
-Net::ARP::get_mac($dev,$mac);
+print $ret ? "ok\n" : "failed\n";
+
+$mac = Net::ARP::get_mac($dev);
 print "MAC $mac\n";
-Net::ARP::arp_lookup($dev,"192.168.1.1",$mac);
-print "192.168.2.1 has got mac $mac\n";
+
+$mac = Net::ARP::arp_lookup($dev,"192.168.1.1");
+print "192.168.1.1 has got mac $mac\n";
 
